@@ -193,9 +193,9 @@ impl Dns {
 
     async fn run_udp_server(&self, bind_addr: &ServerAddr, client: Arc<DnsClient>) -> io::Result<()> {
         let socket = match *bind_addr {
-            ServerAddr::SocketAddr(ref saddr) => ShadowUdpSocket::listen(&saddr).await?,
+            ServerAddr::SocketAddr(ref saddr) => ShadowUdpSocket::listen(saddr).await?,
             ServerAddr::DomainName(ref dname, port) => {
-                lookup_then!(&self.context.context_ref(), dname, port, |addr| {
+                lookup_then!(self.context.context_ref(), dname, port, |addr| {
                     ShadowUdpSocket::listen(&addr).await
                 })?
                 .1
@@ -312,10 +312,10 @@ fn should_forward_by_ptr_name(acl: &AccessControl, name: &Name) -> bool {
 
 fn check_name_in_proxy_list(acl: &AccessControl, name: &Name) -> Option<bool> {
     if name.is_fqdn() {
-        // remove the last dot from FQDN
+        // convert to ASCII representation
         let mut name = name.to_ascii();
-        name.pop();
-        acl.check_host_in_proxy_list(&name)
+        name.make_ascii_lowercase();
+        acl.check_ascii_host_in_proxy_list(&name)
     } else {
         // unconditionally use default for PQDNs
         Some(acl.is_default_in_proxy_list())
