@@ -1,6 +1,10 @@
 //! Shadowsocks Local Utilities
 
-use std::{io, net::SocketAddr, time::Duration};
+use std::{
+    io,
+    net::{Ipv4Addr, Ipv6Addr, SocketAddr},
+    time::Duration,
+};
 
 use log::{debug, trace};
 use shadowsocks::{
@@ -123,3 +127,14 @@ where
 
     Ok(())
 }
+
+/// Helper function for converting IPv4 mapped IPv6 address
+///
+/// This is the same as `Ipv6Addr::to_ipv4_mapped`, but it is still unstable in the current libstd
+#[allow(unused)]
+pub(crate) fn to_ipv4_mapped(ipv6: &Ipv6Addr) -> Option<Ipv4Addr> {
+    match ipv6.octets() {
+        [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0xff, 0xff, a, b, c, d] => Some(Ipv4Addr::new(a, b, c, d)),
+        _ => None,
+    }
+}
